@@ -17,11 +17,9 @@ local err = mt.rcptto(conn, "to@example.com")
 assert(err == nil, err)
 assert(mt.getreply(conn) == SMFIR_CONTINUE)
 
--- TODO mt.data always times out. This is a bug in miltertest, see:
--- https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=946386
--- local err = mt.data(conn)
--- assert(err == nil, err)
--- assert(mt.getreply(conn) == SMFIR_CONTINUE)
+local err = mt.data(conn)
+assert(err == nil, err)
+assert(mt.getreply(conn) == SMFIR_CONTINUE)
 
 local err = mt.header(conn, "Test-Name", "Test-Value")
 assert(err == nil, err)
